@@ -35,6 +35,8 @@
 #include "ut_debugmsg.h"		// UT_DEBUGMSG
 #include "ut_iconv.h"
 #include "ut_assert.h"			// UT_ASSERT
+#include "ut_mbtowc.h"
+#include "ut_bytebuf.h"
 
 //
 // This string class is intended to meet the following requirements.
@@ -82,7 +84,7 @@ UT_String::UT_String()
 }
 
 UT_String::UT_String(const char* sz, size_t n)
-:	pimpl(new UT_Stringbuf(sz, n ? n : (sz ? strlen(sz) : 0)))
+:	pimpl(new UT_Stringbuf(sz, n ? n : (sz && *sz ? strlen(sz) : 0)))
 {
 }
 
@@ -149,7 +151,7 @@ UT_String& UT_String::operator=(const UT_String& rhs)
 
 UT_String& UT_String::operator=(const char* rhs)
 {
-  if (!rhs)
+  if (!rhs || !*rhs)
     pimpl->clear ();
   else
     pimpl->assign(rhs, strlen(rhs));
@@ -174,7 +176,7 @@ UT_String& UT_String::operator+=(const UT_String& rhs)
 
 UT_String& UT_String::operator+=(const char* rhs)
 {
-	UT_return_val_if_fail(rhs, *this);
+	UT_return_val_if_fail(rhs && *rhs, *this);
 	pimpl->append(rhs, strlen(rhs));
 	return *this;
 }
@@ -350,6 +352,9 @@ UT_printf_string_upper_bound (const char* format,
 #  else /* va_list is a pointer */
 #  define VA_COPY(ap1, ap2)	  ((ap1) = (ap2))
 #  endif /* va_list is a pointer */
+#  if defined (__GNUC__)
+#  define VA_COPY(ap1,ap2)     __va_copy((ap1),(ap2))
+#  endif
 #endif /* !VA_COPY */
 
 UT_String& UT_String_vprintf (UT_String & inStr, const char *format,
@@ -700,7 +705,13 @@ char& UT_String::operator[](size_t iPos)
 UT_uint32 hashcode(const UT_String& string)
 {
 	// from glib
-	const char* p = string.c_str();
+	return hashcode(string.c_str());
+}
+
+UT_uint32 hashcode(const char *p)
+{
+	// from glib
+	UT_return_val_if_fail(p,0);
 	UT_uint32 h = (UT_uint32)*p;
 	
 	if (h)
@@ -786,6 +797,28 @@ size_t UT_UTF8String::byteLength () const
 	return pimpl->byteLength ();
 }
 
+void UT_UTF8String::dump (void) const
+{
+#if DEBUG
+	char line[120];
+	UT_sint32 i =0;
+	const char * psz = utf8_str();
+	while(psz && *psz)
+	{
+		for(i=0; (i< 60) && (*psz != 0); i++)
+		{
+			line[i] = *psz;
+			psz++;
+		}
+		line[i] = 0;
+		UT_DEBUGMSG(("%s \n",line));
+		if(*psz == 0)
+		{
+			break;
+		}
+	}
+#endif
+}
 bool UT_UTF8String::empty () const
 {
 	return pimpl->empty ();
@@ -799,7 +832,7 @@ void UT_UTF8String::clear () const
 UT_UTF8String &	UT_UTF8String::operator=(const char * rhs)
 {
   // treat null string assignment as a clear
-  if (!rhs)
+  if (!rhs || !*rhs)
     pimpl->clear();
   else
     pimpl->assign (rhs);
@@ -815,9 +848,17 @@ UT_UTF8String &	UT_UTF8String::operator=(const UT_UTF8String & rhs)
 	return *this;
 }
 
+
+UT_UTF8String &	UT_UTF8String::operator+=(const UT_UCS4Char            rhs)
+{
+	pimpl->appendUCS4 (&rhs, 1);
+	return *this;
+}
+
+
 UT_UTF8String &	UT_UTF8String::operator+=(const char * rhs)
 {
-	UT_return_val_if_fail(rhs, *this);
+	UT_return_val_if_fail(rhs && *rhs, *this);
 	pimpl->append (rhs);
 	return *this;
 }
@@ -843,11 +884,29 @@ void UT_UTF8String::append (const char * sz, size_t n /* == 0 => null-terminatio
 	pimpl->append (sz, n);
 }
 
+void UT_UTF8String::appendBuf (const UT_ByteBuf & buf, UT_UCS4_mbtowc & converter)
+{
+	UT_uint32 i;
+	UT_UCS4Char wc;
+	const UT_Byte *ptr = buf.getPointer(0);
+	
+	for (i = 0; i < buf.getLength(); i++) 
+	{
+	  if (converter.mbtowc(wc, static_cast<char>(ptr[i])))
+	        pimpl->appendUCS4(&wc, 1);
+ 	}
+}
+
 void UT_UTF8String::appendUCS4 (const UT_UCS4Char * sz, size_t n /* == 0 => null-termination */)
 {
 	pimpl->appendUCS4 (sz, n);
 }
 
+void UT_UTF8String::appendUCS2 (const UT_UCS2Char * sz, size_t n /* == 0 => null-termination */)
+{
+	pimpl->appendUCS2 (sz, n);
+}
+
 /* replaces <str1> with <str2> in the current string
  */
 const UT_UTF8String & UT_UTF8String::escape (const UT_UTF8String & str1, const UT_UTF8String & str2)
@@ -872,6 +931,303 @@ const UT_UTF8String & UT_UTF8String::escapeMIME ()
 	return *this;
 }
 
+/* makes string conform to RFC 1738
+ */
+const UT_UTF8String & UT_UTF8String::escapeURL ()
+{
+	pimpl->escapeURL ();
+	return *this;
+}
+
+/* decodes %xx tokens in string
+ */
+const UT_UTF8String & UT_UTF8String::decodeURL ()
+{
+	pimpl->decodeURL ();
+	return *this;
+}
+
+const UT_UTF8String & UT_UTF8String::lowerCase ()
+{
+	if(!byteLength())
+		return *this;
+	
+	UT_UTF8Stringbuf * n = pimpl->lowerCase ();
+	if(n)
+	{
+		delete pimpl;
+		pimpl = n;
+	}
+	
+	return *this;
+}
+
+
+UT_UTF8String  UT_UTF8String::substr(size_t iStart, size_t nChars) const
+{
+	const size_t nSize = pimpl->utf8Length ();
+
+	if (iStart >= nSize || !nChars) {
+		return UT_UTF8String();
+	}
+
+	const char* p = pimpl->data() + iStart;
+	if (iStart + nChars > nSize) {
+		nChars = nSize - iStart;
+	}
+
+	return UT_UTF8String(p, nChars);
+
+}
+
+///////////////////////////////////////////////////////////////////////////
+//
+// Martin's property string functions for UT_UTF8Strings.....
+//
+///////////////////////////////////////////////////////////////////////////
+
+/*!
+ * Assuming a string of standard abiword properties eg. "fred:nerk; table-width:1.0in; table-height:10.in"
+ * Return the value of the property sProp or NULL if it is not present.
+ * This UT_UTF8String * should be deleted by the calling programming after it is finished with it.
+ */
+UT_UTF8String UT_UTF8String_getPropVal(const UT_UTF8String & sPropertyString, const UT_UTF8String & sProp)
+{
+	UT_UTF8String sWork(sProp);
+	sWork += ":";
+
+	const char * szWork = sWork.utf8_str();
+	const char * szProps = sPropertyString.utf8_str();
+	const char * szLoc = strstr(szProps,szWork);
+	if(szLoc == NULL)
+	{
+		return UT_UTF8String();
+	}
+//
+// Look if this is the last property in the string.
+//
+	const char * szDelim = strchr(szLoc,';');
+	if(szDelim == NULL)
+	{
+//
+// Remove trailing spaces
+//
+		UT_sint32 iSLen = strlen(szProps);
+		while(iSLen > 0 && szProps[iSLen-1] == ' ')
+		{
+			iSLen--;
+		}
+//
+// Calculate the location of the substring
+//
+		UT_sint32 offset = static_cast<UT_sint32>(reinterpret_cast<size_t>(szLoc) - reinterpret_cast<size_t>(szProps));
+		offset += strlen(szWork);
+		return UT_UTF8String(sPropertyString.substr(offset,(iSLen - offset)));
+	}
+	else
+	{
+		szDelim = strchr(szLoc,';');
+		if(szDelim == NULL)
+		{
+//
+// bad property string
+//
+			UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+			return UT_UTF8String();
+		}
+//
+// Remove trailing spaces.
+//
+		while(*szDelim == ';' || *szDelim == ' ')
+		{
+			szDelim--;
+		}
+//
+// Calculate the location of the substring
+//
+		UT_sint32 offset = static_cast<UT_sint32>(reinterpret_cast<size_t>(szLoc) - reinterpret_cast<size_t>(szProps));
+		offset += strlen(szWork);
+		UT_sint32 iLen = static_cast<UT_sint32>(reinterpret_cast<size_t>(szDelim) - reinterpret_cast<size_t>(szProps)) + 1;
+		return UT_UTF8String(sPropertyString.substr(offset,(iLen - offset)));
+	}
+}
+/*!
+ * Assuming a string of standard abiword properties eg. "fred:nerk; table-width:1.0in; table-height:10.in"
+ * Add aother propety string, updating previously defined properties with
+ * values in the new string.
+ */
+void UT_UTF8String_addPropertyString(UT_UTF8String & sPropertyString, const UT_UTF8String & sNewProp)
+{
+	UT_sint32 iSize = static_cast<UT_sint32>(sNewProp.size());
+	UT_sint32 iBase  =0;
+	UT_UTF8String sProp;
+	UT_UTF8String sVal;
+	UT_UTF8String sSubStr;
+	const char * szWork = NULL;
+	const char * szLoc = NULL;
+	while(iBase < iSize)
+	{
+		bool bBreakAtEnd = false;
+		sSubStr = sNewProp.substr(iBase, iSize-iBase);
+		szWork = sSubStr.utf8_str();
+		szLoc = strstr(szWork,":");
+		UT_sint32 iextra = 0;
+		if(szLoc)
+		{
+		        UT_sint32 k = iBase;
+			while(*sNewProp.substr(k,k).utf8_str() == ' ')
+			{
+			  k++;
+			  iextra++;
+			}
+			sProp = sNewProp.substr(k,szLoc - szWork-iextra);
+		}
+		else
+		{
+			break;
+		}
+		iBase += szLoc-szWork+1;
+		sSubStr = sNewProp.substr(iBase, iSize-iBase);
+		szWork = sSubStr.utf8_str();
+		szLoc = strstr(szWork,";");
+		if(szLoc)
+		{
+			sVal = sNewProp.substr(iBase,szLoc - szWork);
+			iBase += szLoc-szWork+1;
+		}
+		else
+		{
+			sVal = sNewProp.substr(iBase,iSize-iBase);
+			bBreakAtEnd = true;
+		}
+		if((sProp.size()>0) && (sVal.size() >0))
+		{
+			UT_UTF8String_setProperty(sPropertyString,sProp,sVal);
+		}
+		else
+		{
+			break;
+		}
+		if(bBreakAtEnd)
+		{
+			break;
+		}
+	}
+}
+
+/*!
+ * Assuming a string of standard abiword properties eg. "fred:nerk; table-width:1.0in; table-height:10.in"
+ * Add the property sProp with value sVal to the string of properties. If the property is already present, replace the 
+ * old value with the new value.
+ */
+void UT_UTF8String_setProperty(UT_UTF8String & sPropertyString, const UT_UTF8String & sProp, const UT_UTF8String & sVal)
+{
+//
+// Remove the old value if it exists and tack the new property on the end.
+//
+	UT_UTF8String_removeProperty(sPropertyString, sProp);
+	if(sPropertyString.size() > 0)
+	{
+		sPropertyString += "; ";
+	}
+	sPropertyString += sProp;
+	sPropertyString += ":";
+	sPropertyString += sVal;
+}
+
+/*!
+ * Assuming a string of standard abiword properties eg. "fred:nerk; table-width:1.0in; table-height:10.in"
+ * Remove the property sProp and it's value from the string of properties. 
+ */
+void UT_UTF8String_removeProperty(UT_UTF8String & sPropertyString, const UT_UTF8String & sProp)
+{
+//
+// Warning, warning!!! lots of brutal const casts and assignments into
+// strings to handle utf8 encoding.
+//
+	UT_UTF8String sWork ( sProp );
+	sWork += ":";
+	const char * szWork = sWork.utf8_str();
+	const char * szProps = sPropertyString.utf8_str();
+	const char * szLoc = strstr(szProps,szWork);
+	if(szLoc == NULL)
+	{
+//
+// Not here, do nothing
+		return ;
+	}
+//
+// Found it, Get left part.
+//
+	UT_sint32 locLeft = static_cast<UT_sint32>(reinterpret_cast<size_t>(szLoc) - reinterpret_cast<size_t>(szProps));
+	UT_UTF8String sLeft;
+	if(locLeft == 0)
+	{
+		sLeft.clear();
+	}
+	else
+	{
+		UT_UTF8String sTmp =  sPropertyString;
+		char * szTmp = const_cast<char *>(sTmp.utf8_str());
+		szTmp[locLeft] = 0; 
+		sLeft = szTmp;
+	}
+	char * szLeft = const_cast<char *>(sLeft.utf8_str());
+	locLeft--;
+	if(locLeft > 0)
+	{
+//
+// If this element is the last item in the properties there is no "; ".
+//
+// Remove trailing ';' and ' '
+//
+		while(locLeft >= 0 && (szLeft[locLeft] == ';' || szLeft[locLeft] == ' '))
+		{
+			locLeft--;
+		}
+	}
+	UT_UTF8String sNew;
+	if(locLeft > 0)
+	{
+		szLeft[locLeft+1] = 0;
+		sNew = szLeft;
+	}
+	else
+	{
+		sNew.clear();
+	}
+//
+// Look for ";" to get right part
+//
+	const char * szDelim = strchr(szLoc,';');
+	if(szDelim == NULL)
+	{
+//
+// No properties after this, just assign and return
+//
+		sPropertyString = sNew;
+	}
+	else
+	{
+//
+// Just slice off the properties and tack them onto the pre-existing sNew
+//
+		while(*szDelim == ';' || *szDelim == ' ')
+		{
+			szDelim++;
+		}
+		UT_UTF8String sRight = szDelim;
+		if(sNew.size() > 0)
+		{
+			sNew += "; ";
+		}
+		sNew += sRight;
+		sPropertyString = sNew;
+	}
+}
+
+/////////////////////////////////////////////////////////////////////////////
+
 UT_UCS4String UT_UTF8String::ucs4_str ()
 {
 	UT_UCS4String ucs4string;
@@ -975,7 +1331,7 @@ UT_UCS4String::UT_UCS4String(const char * utf8_str, size_t bytelength /* 0 == ze
 :	pimpl(new UT_UCS4Stringbuf)
 {
 	if (bytelength == 0) {
-		if (utf8_str == 0) return;
+		if (utf8_str == 0 || *utf8_str == '\0') return;
 		bytelength = strlen (utf8_str);
 	}
 	while (true) {
@@ -994,7 +1350,7 @@ UT_UCS4String::UT_UCS4String(const char * utf8_str, size_t bytelength /* 0 == ze
 :	pimpl(new UT_UCS4Stringbuf)
 {
 	if (bytelength == 0) {
-		if (utf8_str == 0) return;
+		if (utf8_str == 0 || *utf8_str == '\0') return;
 		bytelength = strlen (utf8_str);
 	}
 	UT_UCS4Char ucs4a = UT_UCS4Stringbuf::UTF8_to_UCS4 (utf8_str, bytelength);
