@@ -22,6 +22,7 @@
 
 #include "xap_Dlg_Insert_Symbol.h"
 #include "xap_UnixFontManager.h"
+#include "gr_UnixGraphics.h"
 #include <gdk/gdkkeysyms.h>
 
 #define DEFAULT_UNIX_SYMBOL_FONT "Symbol"
@@ -76,8 +77,7 @@ private:
 	GtkWidget * m_SymbolMap;
 	GtkWidget * m_fontcombo;	
 	GList     * m_InsertS_Font_list;
-	UT_Vector   m_fontlist;
-	UT_uint32   m_Insert_Symbol_no_fonts;
+	UT_GenericVector<gchar*>   m_fontlist;
 
 #ifndef USE_GUCHARMAP
 	// private construction functions
