@@ -102,7 +102,8 @@ fl_TableLayout::fl_TableLayout(FL_DocLayout* pLayout, PL_StruxDocHandle sdh,
 	  m_iNumNestedTables(0),
 	  m_bIsEndTableIn(false),
 	  m_iHeightChanged(0),
-      m_pNewHeightCell(NULL)
+      m_pNewHeightCell(NULL),
+	  m_bDoingDestructor(false)
 
 {
 	UT_DEBUGMSG(("Created Table Layout %x \n",this));
@@ -116,6 +117,7 @@ fl_TableLayout::~fl_TableLayout()
 {
 	// NB: be careful about the order of these
 	UT_DEBUGMSG(("SEVIOR: !!!!!!!! Deleting tableLayout  %x !! \n",this));
+	m_bDoingDestructor = true;
 	_purgeLayout();
 	fp_TableContainer * pTC = static_cast<fp_TableContainer *>(getFirstContainer());
 	if (pTC)
@@ -251,6 +253,7 @@ void fl_TableLayout::insertTableContainer( fp_TableContainer * pNewTab)
 	fl_ContainerLayout * pPrevL = static_cast<fl_ContainerLayout *>(getPrev());
 	fp_Container * pPrevCon = NULL;
 	fp_Container * pUpCon = NULL;
+	fp_Line * pPrevLine = NULL;
 	if(pPrevL != NULL )
 	{
 		while(pPrevL && (pPrevL != pUPCL) && ((pPrevL->getContainerType() == FL_CONTAINER_FOOTNOTE)
@@ -314,6 +317,22 @@ void fl_TableLayout::insertTableContainer( fp_TableContainer * pNewTab)
 				{
 					pPrevL = NULL;
 				}
+				if(pPrevCon && pPrevCon->getContainerType() == FP_CONTAINER_LINE)
+				{
+					pPrevLine = static_cast<fp_Line *>(pPrevCon);
+					if(pPrevLine->containsForcedPageBreak())
+					{
+						pUpCon = pPrevLine->getContainer();
+						while(pUpCon && pUpCon->getPage() == pPrevLine->getPage())
+						{
+							pUpCon = static_cast<fp_Container *>(pUpCon->getNext());
+						}
+					}
+					if(pUpCon == NULL)
+					{
+							pUpCon = pPrevLine->getContainer();
+					}
+				}
 			}
 		}
 		else
@@ -371,6 +390,11 @@ void fl_TableLayout::insertTableContainer( fp_TableContainer * pNewTab)
 				pUpCon->addCon(pNewTab);
 				pNewTab->setContainer(pUpCon);
 			}
+			else if( i < 0)
+			{
+				pUpCon->insertConAt(pNewTab,0);
+				pNewTab->setContainer(pUpCon);
+			}
 			else
 			{
 				UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
@@ -2293,6 +2317,10 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 
 	}
 	defaultOffset = "0.01in";
+
+	static UT_sint32 idefaultOffsetLogicalUnits =  UT_convertToLogicalUnits("0.01in");
+	static double idefaultOffsetDimensionless =  UT_convertDimensionless("0.01in");
+
 	if(pszLeftOffset && pszLeftOffset[0])
 	{
 		m_iLeftOffset = UT_convertToLogicalUnits(pszLeftOffset);
@@ -2300,8 +2328,8 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	}
 	else
 	{
-		m_iLeftOffset = UT_convertToLogicalUnits(defaultOffset.c_str());
-		m_dLeftOffsetUserUnits = UT_convertDimensionless(defaultOffset.c_str());
+		m_iLeftOffset = idefaultOffsetLogicalUnits;
+		m_dLeftOffsetUserUnits = idefaultOffsetDimensionless;
 	}
 
 	if(pszTopOffset && pszTopOffset[0])
@@ -2311,8 +2339,8 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	}
 	else
 	{
-		m_iTopOffset = UT_convertToLogicalUnits(defaultOffset.c_str());
-		m_dTopOffsetUserUnits = UT_convertDimensionless(defaultOffset.c_str());
+		m_iTopOffset = idefaultOffsetLogicalUnits;
+		m_dTopOffsetUserUnits = idefaultOffsetDimensionless;
 	}
 
 	if(pszRightOffset && pszRightOffset[0])
@@ -2322,8 +2350,8 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	}
 	else
 	{
-		m_iRightOffset = UT_convertToLogicalUnits(defaultOffset.c_str());
-		m_dRightOffsetUserUnits = UT_convertDimensionless(defaultOffset.c_str());
+		m_iRightOffset = idefaultOffsetLogicalUnits;
+		m_dRightOffsetUserUnits = idefaultOffsetDimensionless;
 	}
 
 	if(pszBottomOffset && pszBottomOffset[0])
@@ -2333,8 +2361,8 @@ void fl_CellLayout::_lookupProperties(const PP_AttrProp* pSectionAP)
 	}
 	else
 	{
-		m_iBottomOffset = UT_convertToLogicalUnits(defaultOffset.c_str());
-		m_dBottomOffsetUserUnits = UT_convertDimensionless(defaultOffset.c_str());
+		m_iBottomOffset = idefaultOffsetLogicalUnits;
+		m_dBottomOffsetUserUnits = idefaultOffsetDimensionless;
 	}
 	const char* pszLeftAttach = NULL;
 	const char* pszRightAttach = NULL;
@@ -2519,6 +2547,37 @@ void fl_CellLayout::_localCollapse(void)
 		pCL = pCL->getNext();
 	}
 }
+/*!
+ * Return the total length of the cell including nested tables.
+ * This length includes the cell and endcell struxs so if you add it
+ * to the position of the cell strux you will get the first position 
+ * past the endcell strux
+ */
+UT_uint32 fl_CellLayout::getLength(void)
+{
+	PL_StruxDocHandle sdhCell = getStruxDocHandle();
+	PL_StruxDocHandle sdhEnd = m_pDoc->getEndCellStruxFromCellSDH(sdhCell);
+	PT_DocPosition posEnd = 0;
+	PT_DocPosition posStart = 0;
+	UT_uint32 len = 0;
+	if(sdhCell && (sdhEnd == NULL)) // handle case of endStrux not in yet
+	{
+		posStart = m_pDoc->getStruxPosition(sdhCell);
+		m_pDoc->getBounds(true,posEnd);
+		len = posEnd - posStart + 1;
+	}
+	else if(sdhCell == NULL)
+	{
+		return 0;
+	}
+	else
+	{
+		posEnd = m_pDoc->getStruxPosition(sdhEnd);
+		len = posEnd -  m_pDoc->getStruxPosition(sdhCell) + 1;
+	}
+	return len;
+}
+
 
 void fl_CellLayout::collapse(void)
 {
