@@ -24,6 +24,7 @@
 #include "pd_Document.h"
 #include "fl_BlockLayout.h"
 #include "ut_debugmsg.h"
+#include "ut_locale.h"
 #include "pd_Document.h"
 #include "ut_mbtowc.h"
 #include "fp_Page.h"
@@ -67,6 +68,8 @@ void fp_EmbedRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 									const PP_AttrProp * /*pSectionAP*/,
 									GR_Graphics * pG)
 {
+	UT_return_if_fail(pSpanAP != NULL);
+
 	UT_DEBUGMSG(("fp_EmbedRun _lookupProperties span %x \n",pSpanAP));
 	m_pSpanAP = pSpanAP;
 	m_bNeedsSnapshot = true;
@@ -108,6 +111,7 @@ void fp_EmbedRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 	  m_iEmbedUID = getEmbedManager()->makeEmbedView(pDoc,m_iIndexAP,m_pszDataID);
 	  UT_DEBUGMSG((" EmbedRun %x UID is %d \n",this,m_iEmbedUID));
 	  getEmbedManager()->initializeEmbedView(m_iEmbedUID);
+	  getEmbedManager()->setRun (m_iEmbedUID, this);
 	  getEmbedManager()->loadEmbedData(m_iEmbedUID);
 	}
 	getEmbedManager()->setDefaultFontSize(m_iEmbedUID,atoi(pszSize));
@@ -123,6 +127,9 @@ void fp_EmbedRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 	  bool bFoundHeight = pSpanAP->getProperty("height", pszHeight);
 	  const char * pszWidth = NULL;
 	  bool bFoundWidth = pSpanAP->getProperty("width", pszWidth);
+	  const char * pszAscent = NULL;
+	  bool bFoundAscent = pSpanAP->getProperty("ascent", pszAscent);
+
 	  if(!bFoundWidth || pszWidth == NULL)
 	  {
 	      iWidth = getEmbedManager()->getWidth(m_iEmbedUID);
@@ -132,22 +139,36 @@ void fp_EmbedRun::_lookupProperties(const PP_AttrProp * pSpanAP,
 	      iWidth = UT_convertToLogicalUnits(pszWidth);
 	      if(iWidth <= 0)
 	      {
-		  iWidth = getEmbedManager()->getWidth(m_iEmbedUID);
+			  iWidth = getEmbedManager()->getWidth(m_iEmbedUID);
 	      }
 	  }
-	  if(!bFoundHeight || pszHeight == NULL)
+	  if(!bFoundHeight || pszHeight == NULL || !bFoundAscent || pszAscent == NULL)
 	  {
 	      iAscent = getEmbedManager()->getAscent(m_iEmbedUID);
+		  iDescent = getEmbedManager()->getDescent(m_iEmbedUID);
 	  }
 	  else
 	  {
-	      iAscent = UT_convertToLogicalUnits(pszHeight);
+	      iAscent = UT_convertToLogicalUnits(pszAscent);
 	      if(iAscent <= 0)
 	      {
-		  iAscent = getEmbedManager()->getAscent(m_iEmbedUID);
+			  iAscent = getEmbedManager()->getAscent(m_iEmbedUID);
+			  iDescent = getEmbedManager()->getDescent(m_iEmbedUID);
 	      }
+		  else
+		  {
+			  UT_sint32 iHeight = UT_convertToLogicalUnits(pszHeight);
+			  const char * pszDescent = NULL;
+			  bool bFoundDescent = pSpanAP->getProperty("descent", pszDescent);
+			  if (bFoundDescent && pszDescent != NULL)
+			  {
+				  iDescent = UT_convertToLogicalUnits(pszDescent);
+				  if (iHeight != iAscent + iDescent)
+					  iAscent = iHeight * iAscent / (iAscent + iDescent);
+			  }
+			  iDescent = iHeight - iAscent;
+		  }
 	  }
-	  iDescent = getEmbedManager()->getDescent(m_iEmbedUID);
 	}
 	UT_DEBUGMSG(("Width = %d Ascent = %d Descent = %d \n",iWidth,iAscent,iDescent)); 
 
@@ -513,7 +534,8 @@ bool fp_EmbedRun::_updatePropValuesIfNeeded(void)
   if(bDoUpdate)
     {
       const char * pProps[10] = {NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL};
-      UT_UTF8String sHeight,sWidth,sAscent,sDescent;
+	  UT_LocaleTransactor t(LC_NUMERIC, "C");
+	  UT_UTF8String sHeight,sWidth,sAscent,sDescent;
       UT_UTF8String_sprintf(sHeight,"%fin",static_cast<double>(getHeight())/1440.);
       pProps[0] = "height";
       pProps[1] = sHeight.utf8_str();
