@@ -39,53 +39,6 @@
 #include "pd_Document.h"
 
 
-/*!
-    XML cannot contain any control characters except \t, \n, \r, see bug 8565
-    (http://www.w3.org/TR/REC-xml/#charsets)
-    
-    This function replaces any illegal characters with '~'
-    (That choice is arbitrary, it needs to be some character that does not have a special
-    meaning in xml, xlink, etc. We could, of course, remove the character altoghether, but
-    that means moving data around.)
-*/
-static inline void s_validXML(char * s)
-{
-	if(!s)
-		return;
-	
-	while(*s)
-	{
-		if(*s < ' ' && *s >= 0 && *s != '\t' && *s != '\n' && *s != '\r')
-		{
-			*s = '~';
-		}
-		
-		++s;
-	}
-}
-
-/*! \fn static inline bool s_isValidXML(const char *s)
-	 \param s The string of characters which is to be checked for XML-validity.
-	 \retval TRUE if the characters are all valid for XML, FALSE if any one of them is not.
-*/
-static inline bool s_isValidXML(const char *s)
-{
-	if(!s)
-		return true;
-	
-	while(*s)
-	{
-		if(*s < ' ' && *s != '\t' && *s != '\n' && *s != '\r')
-		{
-			return false;
-		}
-		
-		++s;
-	}
-
-	return true;
-}
-	
 /****************************************************************/
 
 /// This is the sole explicit constructor of class PP_AttrProp.
@@ -380,8 +333,8 @@ bool	PP_AttrProp::setAttribute(const XML_Char * szName, const XML_Char * szValue
 		char * szDupValue = szValue ? UT_strdup(szValue) : NULL;
 
 		// get rid of any illegal chars we might have been given
-		s_validXML(copy);
-		s_validXML(szDupValue);
+		UT_validXML(copy);
+		UT_validXML(szDupValue);
 
 		const char * pEntry = m_pAttributes->pick(copy);
 
@@ -437,12 +390,12 @@ bool	PP_AttrProp::setProperty(const XML_Char * szName, const XML_Char * szValue)
 
 	// get rid of any chars invalid in xml
 	char * szName2 = NULL;
-	if(!s_isValidXML(szName))
+	if(!UT_isValidXML(szName))
 	{
 		szName2 = UT_strdup(szName);
 
 		// get rid of any illegal chars we were passed
-		s_validXML(szName2);
+		UT_validXML(szName2);
 
 		szName = szName2;
 	}
@@ -451,7 +404,7 @@ bool	PP_AttrProp::setProperty(const XML_Char * szName, const XML_Char * szValue)
 	UT_return_val_if_fail( szName && (szValue2 || !szValue), false);
 
 	// get rid of any illegal chars we might have been given in the value
-	s_validXML(szValue2);
+	UT_validXML(szValue2);
 	
 	const PropertyPair * pEntry = m_pProperties->pick(szName);
 	if (pEntry)
@@ -1011,7 +964,8 @@ void PP_AttrProp::_clearEmptyProperties()
 		{
 			const PropertyPair* p = pEntry;
 
-			if(*(p->first()) == 0)
+			const char *s = p->first();
+			if(s == NULL || *s == 0)
 			{
 
 				XML_Char* tmp = const_cast<XML_Char*>(p->first());
