@@ -148,6 +148,10 @@ bool pt_PieceTable::_unlinkStrux_Block(pf_Frag_Strux * pfs,
 	// find the previous strux (either a paragraph or something else).
 
 	pf_Frag_Strux * pfsPrev = NULL;
+	if(m_fragments.areFragsDirty())
+	{
+	    getFragments().cleanFrags(); // clean up to be safe...
+	}
 	_getStruxFromPosition(pfs->getPos(),&pfsPrev, true); // should that really skip footnotes?
 	UT_return_val_if_fail (pfsPrev, false);			// we have a block that's not in a section ??
 	//
@@ -175,22 +179,60 @@ bool pt_PieceTable::_unlinkStrux_Block(pf_Frag_Strux * pfs,
 		// we are the first paragraph in this section.  if we have
 		// content, we cannot be deleted, since there is no one to
 		// inherit our content.
-
-		if (_struxHasContent(pfs))
+	  UT_DEBUGMSG(("Prev frag is section in delete strux block \n"));
+		if (!_struxIsEmpty(pfs))
 		{
 			// TODO decide if this should assert or just fail...
 			UT_DEBUGMSG(("Cannot delete first paragraph with content.\n"));
 			UT_ASSERT_HARMLESS(0);
 			return false;
 		}
-
+		//
+		// Check to see if this is the first section of the document.
+		//
+		if(pfsPrev->getPrev() == NULL)
+		{
+		  pf_Frag * pfNext = pfs->getNext();
+		  if(pfNext == NULL)
+		  {
+		    //
+		    // Cannot delete this because then there will be no page
+		    //
+			UT_DEBUGMSG(("Cannot delete only paragraph.\n"));
+			UT_ASSERT_HARMLESS(0);
+			return false;
+		  }
+		  if(pfNext->getType() == pf_Frag::PFT_Strux)
+		  {
+		      pf_Frag_Strux * pfsNext = static_cast<pf_Frag_Strux *>(pfNext);
+		      if(pfsNext->getStruxType() == PTX_SectionHdrFtr)
+		      {
+		    //
+		    // Cannot delete this because then there will be no page
+		    //
+			  UT_DEBUGMSG(("Cannot delete only paragraph.\n"));
+			  UT_ASSERT_HARMLESS(0);
+			  return false;
+		      }  
+		      if(pfsNext->getStruxType() == PTX_SectionFrame)
+		      {
+		    //
+		    // Cannot delete this because then there will be nowhere
+		    // for the frame
+		    //
+			  UT_DEBUGMSG(("Cannot delete becase we need the frame.\n"));
+			  UT_ASSERT_HARMLESS(0);
+			  return false;
+		      }
+		  }  
+		}
 
 	case PTX_SectionHdrFtr:
 		// we are the first paragraph in this section.  if we have
 		// content, we cannot be deleted, since there is no one to
 		// inherit our content.
 
-		if (_struxHasContent(pfs))
+		if (!_struxIsEmpty(pfs))
 		{
 			// TODO decide if this should assert or just fail...
 			UT_DEBUGMSG(("Cannot delete first paragraph with content.\n"));
