@@ -60,13 +60,15 @@ public:
     fd_Field *              getField(void) const {return m_field;}; 
     PL_ObjectHandle                     getObjectHandle(void) const
       { return  m_OH;}
+    void                    setObjectHandle(pf_Frag_Object * pfo) const
+    { m_OH = static_cast<PL_ObjectHandle>(pfo);}
 protected:
 	PTObjectType			m_objectType;		/* our type (image, etc.) */
 	PT_BlockOffset			m_blockOffset; /* offset of span from beginning of paragraph */
     // this only serves as a unique identifier of a field
     // it should not be thought of as a valid pointer
     fd_Field *              m_field; 
-    PL_ObjectHandle         m_OH;
+    mutable PL_ObjectHandle         m_OH;
 };
 
 #endif /* PX_CHANGERECORD_OBJECT_H */
