@@ -17,22 +17,20 @@
  * 02111-1307, USA.
  */
 
-#undef GTK_DISABLE_DEPRECATED
-
 #include <stdlib.h>
 #include <glade/glade.h>
+#include <gdk/gdk.h>
 #include "ut_locale.h"
 
 #include "ut_string.h"
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
+#include "ut_unixMisc.h"
 
 // This header defines some functions for Unix dialogs,
 // like centering them, measuring them, etc.
 #include "xap_UnixDialogHelper.h"
 
-#include "xap_UnixGtkColorPicker.h"
-
 #include "xap_App.h"
 #include "xap_UnixApp.h"
 #include "xap_Frame.h"
@@ -89,18 +87,6 @@ static void s_line_bottom(GtkWidget *widget, gpointer data )
 	dlg->event_previewExposed();
 }
 
-static void s_border_color(GtkWidget *widget, gpointer data )
-{
-	AP_UnixDialog_FormatTable * dlg = static_cast<AP_UnixDialog_FormatTable *>(data);
-	UT_return_if_fail(widget && dlg);
-	
-	guint8 r, g, b, a;
-	gtk_color_picker_get_i8 (GTK_COLOR_PICKER(widget), &r, &g, &b, &a);
-	dlg->setBorderColor(UT_RGBColor(r,g,b));
-	dlg->event_previewExposed();
-}
-
-
 static void s_border_thickness(GtkWidget *widget, gpointer data )
 {
 	AP_UnixDialog_FormatTable * dlg = static_cast<AP_UnixDialog_FormatTable *>(data);
@@ -108,17 +94,6 @@ static void s_border_thickness(GtkWidget *widget, gpointer data )
 	dlg->event_BorderThicknessChanged();
 }
 
-static void s_background_color(GtkWidget *widget, gpointer data)
-{
-	AP_UnixDialog_FormatTable * dlg = static_cast<AP_UnixDialog_FormatTable *>(data);
-	UT_return_if_fail(widget && dlg);
-	
-	guint8 r, g, b, a;
-	gtk_color_picker_get_i8 (GTK_COLOR_PICKER(widget), &r, &g, &b, &a);
-	dlg->setBackgroundColor(UT_RGBColor(r,g,b));
-	dlg->event_previewExposed();
-}
-
 static gboolean s_preview_exposed(GtkWidget * widget, gpointer /* data */, AP_UnixDialog_FormatTable * dlg)
 {
 	UT_return_val_if_fail(widget && dlg, FALSE);
@@ -151,6 +126,92 @@ static gboolean s_remove_image(GtkWidget *widget, gpointer data)
 	return FALSE;
 }
 
+/*!
+* Intercept clicks on the color button and show an own GtkColorSelectionDialog
+* with palette enabled.
+*/
+static gboolean 
+AP_UnixDialog_FormatTable__onBorderColorClicked (GtkWidget 		*button,
+												 GdkEventButton *event,
+												 gpointer 		data)
+{
+	// only handle left clicks
+	if (event->button != 1) {
+		return FALSE;
+	}
+
+	AP_UnixDialog_FormatTable *dlg = static_cast<AP_UnixDialog_FormatTable *>(data);
+	UT_return_val_if_fail (button && dlg, FALSE);
+
+	GtkWidget *colordlg = gtk_color_selection_dialog_new  ("");
+	gtk_window_set_transient_for (GTK_WINDOW (colordlg), GTK_WINDOW (dlg->getWindow ()));
+	GtkColorSelection *colorsel = GTK_COLOR_SELECTION ((GTK_COLOR_SELECTION_DIALOG (colordlg))->colorsel);
+	gtk_color_selection_set_has_palette (colorsel, TRUE);
+	
+	gint result = gtk_dialog_run (GTK_DIALOG (colordlg));
+	if (result == GTK_RESPONSE_OK) {
+		
+		// update button
+		GtkColorButton *colorbtn = GTK_COLOR_BUTTON (button);
+		GdkColor color;
+		gtk_color_selection_get_current_color (colorsel, &color);
+		gtk_color_button_set_color (colorbtn, &color);
+
+		// update dialog
+		UT_RGBColor* rgb = UT_UnixGdkColorToRGBColor (color);
+		dlg->setBorderColor (*rgb);
+		DELETEP (rgb);
+		dlg->event_previewExposed ();
+	}
+		
+	// do not propagate further
+	gtk_widget_destroy (colordlg);
+	return TRUE;
+}
+
+/*!
+* Intercept clicks on the color button and show an own GtkColorSelectionDialog
+* with palette enabled.
+*/
+static gboolean 
+AP_UnixDialog_FormatTable__onBackgroundColorClicked (GtkWidget 		*button,
+													 GdkEventButton *event,
+													 gpointer 		data)
+{
+	// only handle left clicks
+	if (event->button != 1) {
+		return FALSE;
+	}
+
+	AP_UnixDialog_FormatTable *dlg = static_cast<AP_UnixDialog_FormatTable *>(data);
+	UT_return_val_if_fail (button && dlg, FALSE);
+
+	GtkWidget *colordlg = gtk_color_selection_dialog_new  ("");
+	gtk_window_set_transient_for (GTK_WINDOW (colordlg), GTK_WINDOW (dlg->getWindow ()));
+	GtkColorSelection *colorsel = GTK_COLOR_SELECTION ((GTK_COLOR_SELECTION_DIALOG (colordlg))->colorsel);
+	gtk_color_selection_set_has_palette (colorsel, TRUE);
+	
+	gint result = gtk_dialog_run (GTK_DIALOG (colordlg));
+	if (result == GTK_RESPONSE_OK) {
+		
+		// update button
+		GtkColorButton *colorbtn = GTK_COLOR_BUTTON (button);
+		GdkColor color;
+		gtk_color_selection_get_current_color (colorsel, &color);
+		gtk_color_button_set_color (colorbtn, &color);
+
+		// update dialog
+		UT_RGBColor* rgb = UT_UnixGdkColorToRGBColor (color);
+		dlg->setBackgroundColor (*rgb);
+		DELETEP (rgb);
+		dlg->event_previewExposed ();
+	}
+		
+	// do not propagate further
+	gtk_widget_destroy (colordlg);
+	return TRUE;
+}
+
 /*****************************************************************/
 
 #define	WIDGET_ID_TAG_KEY "id"
@@ -291,7 +352,9 @@ void AP_UnixDialog_FormatTable::setBorderThicknessInGUI(UT_UTF8String & sThick)
 
 void AP_UnixDialog_FormatTable::setBackgroundColorInGUI(UT_RGBColor clr)
 {
-	gtk_color_picker_set_i8(GTK_COLOR_PICKER(m_wBackgroundColorButton), clr.m_red, clr.m_grn, clr.m_blu, 0 /* unused */);
+	GdkColor* color = UT_UnixRGBColorToGdkColor(clr);
+	gtk_color_button_set_color (GTK_COLOR_BUTTON (m_wBackgroundColorButton), color);
+	gdk_color_free(color);
 }
 
 void AP_UnixDialog_FormatTable::event_BorderThicknessChanged(void)
@@ -303,7 +366,7 @@ void AP_UnixDialog_FormatTable::event_BorderThicknessChanged(void)
 
 		UT_UTF8String sThickness;
 		{
-			UT_LocaleTransactor(LC_NUMERIC, "C");
+			UT_LocaleTransactor t(LC_NUMERIC, "C");
 			sThickness = UT_UTF8String_sprintf("%fin",thickness);
 		}
 
@@ -434,18 +497,9 @@ GtkWidget * AP_UnixDialog_FormatTable::_constructWindow(void)
 	localizeLabelMarkup(glade_xml_get_widget(xml, "lbPreview"), pSS, AP_STRING_ID_DLG_FormatTable_Preview);
 
 	localizeLabel(glade_xml_get_widget(xml, "lbApplyTo"), pSS, AP_STRING_ID_DLG_FormatTable_Apply_To);
-	
-	// add the custom color picker buttons to the dialog
-	m_wBorderColorButton = gtk_color_picker_new();
-	gtk_widget_show(m_wBorderColorButton);
-	gtk_table_attach(GTK_TABLE (glade_xml_get_widget(xml, "tbBorder")), m_wBorderColorButton, 3, 4, 1, 2,
-                    (GtkAttachOptions) (GTK_FILL), (GtkAttachOptions) (0), 
-					0, 0);
-					
-	// add the custom color picker buttons to the dialog
-	m_wBackgroundColorButton = gtk_color_picker_new();
-	gtk_widget_show(m_wBackgroundColorButton);
-	gtk_box_pack_start(GTK_BOX (glade_xml_get_widget(xml, "hbBackgroundColor")), m_wBackgroundColorButton, TRUE, TRUE, 0);	
+
+	m_wBorderColorButton = glade_xml_get_widget(xml, "cbtBorderColorButton");
+	m_wBackgroundColorButton = glade_xml_get_widget(xml, "cbtBackgroundColorButton");
 
 //
 // Now the Border Thickness Option menu
@@ -558,14 +612,14 @@ void AP_UnixDialog_FormatTable::_connectSignals(void)
 							reinterpret_cast<gpointer>(this));		   
 						   
 	g_signal_connect(G_OBJECT(m_wBorderColorButton),
-							"color_set",
-							G_CALLBACK(s_border_color),
+							"button-release-event",
+							G_CALLBACK(AP_UnixDialog_FormatTable__onBorderColorClicked),
 							reinterpret_cast<gpointer>(this));
 
 	g_signal_connect(G_OBJECT(m_wBackgroundColorButton),
-							"color_set",
-							G_CALLBACK(s_background_color),
-							reinterpret_cast<gpointer>(this));	   
+							"button-release-event",
+							G_CALLBACK(AP_UnixDialog_FormatTable__onBackgroundColorClicked),
+							reinterpret_cast<gpointer>(this));
 						   
 	g_signal_connect(G_OBJECT(m_wPreviewArea),
 							"expose_event",
