@@ -17,6 +17,8 @@
  * 02111-1307, USA.
  */
 
+#include "ap_Features.h"
+
 #include "ut_assert.h"
 #include "ut_vector.h"
 #include "ut_locale.h"
@@ -146,8 +148,10 @@ bool AP_UnixToolbar_StyleCombo::repopulate(void)
 			UT_DEBUGMSG(("no style instance for '%s'\n", szName));
 		}
 
+		/* TODO Numbered Headings are also lists, we need to show them tough
 		if (pStyle->isList())
 			continue;
+		*/
 
 		list = g_slist_prepend (list, (char *)szName);
 
