@@ -25,6 +25,8 @@
 #include <stdio.h>
 #include <string.h>
 
+#include "ap_Features.h"
+
 #include "ut_assert.h"
 #include "ut_debugmsg.h"
 #include "ut_exception.h"
@@ -113,7 +115,6 @@ void AP_Dialog_Options::_storeWindowData(void)
 	Save_Pref_Bool( pPrefsScheme, AP_PREF_KEY_SpellCheckCaps, _gatherSpellUppercase() );
 	Save_Pref_Bool( pPrefsScheme, AP_PREF_KEY_SpellCheckNumbers, _gatherSpellNumbers() );
 	Save_Pref_Bool(pPrefsScheme, AP_PREF_KEY_ShowSplash,_gatherShowSplash());
-	Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_SmartQuotesEnable, _gatherSmartQuotesEnable() );
 
 	Save_Pref_Bool( pPrefsScheme, AP_PREF_KEY_CursorBlink, _gatherViewCursorBlink() );
 	
@@ -135,7 +136,6 @@ void AP_Dialog_Options::_storeWindowData(void)
 #endif
 	Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_AutoLoadPlugins, _gatherAutoLoadPlugins() );
 	Save_Pref_Bool( pPrefsScheme, AP_PREF_KEY_DefaultDirectionRtl, _gatherOtherDirectionRtl() );
-	Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_UseHebrewContextGlyphs, _gatherOtherHebrewContextGlyphs() );
 	Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_ChangeLanguageWithKeyboard, _gatherLanguageWithKeyboard() );
 	Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_DirMarkerAfterClosingParenthesis, _gatherDirMarkerAfterClosingParenthesis());
 	
@@ -292,21 +292,11 @@ void AP_Dialog_Options::_storeDataForControl (tControl id)
 					_gatherSpellNumbers());
 			break;
 
-		case id_CHECK_SMART_QUOTES_ENABLE:
-			Save_Pref_Bool (pPrefsScheme, XAP_PREF_KEY_SmartQuotesEnable,
-					_gatherSmartQuotesEnable());
-			break;
-
 		case id_CHECK_OTHER_DEFAULT_DIRECTION_RTL:
 			Save_Pref_Bool (pPrefsScheme, AP_PREF_KEY_DefaultDirectionRtl,
 					_gatherOtherDirectionRtl());
 			break;
 
-		case id_CHECK_OTHER_HEBREW_CONTEXT_GLYPHS:
-			Save_Pref_Bool (pPrefsScheme, XAP_PREF_KEY_UseHebrewContextGlyphs,
-					_gatherOtherHebrewContextGlyphs() );
-			break;
-
 		case id_CHECK_AUTO_SAVE_FILE:
 			UT_DEBUGMSG(("Saving Auto Save File [%i]\n", _gatherAutoSaveFile()));
 			Save_Pref_Bool( pPrefsScheme, XAP_PREF_KEY_AutoSaveFile, _gatherAutoSaveFile() );
@@ -489,10 +479,6 @@ void AP_Dialog_Options::_populateWindowData(void)
 	if (pPrefs->getPrefsValueBool((XML_Char*)AP_PREF_KEY_AutoGrammarCheck,&b))
 		_setGrammarCheck (b);
 
-	// ------------ Smart Quotes
-	if (pPrefs->getPrefsValueBool((XML_Char*)XAP_PREF_KEY_SmartQuotesEnable,&b))
-		_setSmartQuotesEnable (b);
-
 	// ------------ Prefs
 	_setPrefsAutoSave( pPrefs->getAutoSavePrefs() );
 
@@ -567,8 +553,6 @@ void AP_Dialog_Options::_populateWindowData(void)
 	//------------- other
 	if (pPrefs->getPrefsValueBool(AP_PREF_KEY_DefaultDirectionRtl,&b))
 		_setOtherDirectionRtl (b);
-	if (pPrefs->getPrefsValueBool(XAP_PREF_KEY_UseHebrewContextGlyphs,&b))
-		_setOtherHebrewContextGlyphs (b);
 
 	if (pPrefs->getPrefsValueBool(XAP_PREF_KEY_ChangeLanguageWithKeyboard,&b))
 		_setLanguageWithKeyboard (b);
@@ -703,7 +687,7 @@ AP_PreferenceScheme::AP_PreferenceScheme(AP_PreferenceSchemeManager * pSchemeMan
 	UT_uint32 i = 0;
 	UT_uint32 count = static_cast<UT_uint32>(bo__count);
 
-	for (UT_uint32 i = 0; i < count; i++)
+	for (i = 0; i < count; i++)
 		{
 			BoolOption bo = static_cast<BoolOption>(i);
 
@@ -712,7 +696,7 @@ AP_PreferenceScheme::AP_PreferenceScheme(AP_PreferenceSchemeManager * pSchemeMan
 		}
 	lookupDefaultOptionValues();
 
-	for (UT_uint32 i = 0; i < count; i++)
+	for (i = 0; i < count; i++)
 		{
 			BoolOption bo = static_cast<BoolOption>(i);
 
@@ -735,8 +719,6 @@ AP_PreferenceScheme::AP_PreferenceScheme(AP_PreferenceSchemeManager * pSchemeMan
 		m_BOData[bo_DirectionRTL	].m_original = bValue;
 	if (m_pPrefsScheme->getValueBool(XAP_PREF_KEY_SaveContextGlyphs,					&bValue))
 		m_BOData[bo_GlyphSaveVisual	].m_original = bValue;
-	if (m_pPrefsScheme->getValueBool(XAP_PREF_KEY_UseHebrewContextGlyphs,				&bValue))
-		m_BOData[bo_GlyphShaping	].m_original = bValue;
 
 	// NOT (YET?) IMPLEMENTED: if (m_pPrefsScheme->getValueBool("",&bValue)) m_BOData[bo_HighlightMisspelled].m_original = bValue;
 
@@ -760,8 +742,6 @@ AP_PreferenceScheme::AP_PreferenceScheme(AP_PreferenceSchemeManager * pSchemeMan
 
 	// TODO: if (m_pPrefsScheme->getValueBool("",&bValue)) m_BOData[bo_ScreenColor			].m_original = bValue;
 
-	if (m_pPrefsScheme->getValueBool(XAP_PREF_KEY_SmartQuotesEnable,					&bValue))
-		m_BOData[bo_SmartQuotes		].m_original = bValue;
 	if (m_pPrefsScheme->getValueBool( AP_PREF_KEY_ShowSplash,							&bValue))
 		m_BOData[bo_Splash			].m_original = bValue;
 	if (m_pPrefsScheme->getValueBool( AP_PREF_KEY_StatusBarVisible,						&bValue))
@@ -781,7 +761,7 @@ AP_PreferenceScheme::AP_PreferenceScheme(AP_PreferenceSchemeManager * pSchemeMan
 	// NOT (YET?) IMPLEMENTED: if (m_pPrefsScheme->getValueBool("",&bValue)) m_BOData[bo_ViewAll			].m_original = bValue;
 	// NOT (YET?) IMPLEMENTED: if (m_pPrefsScheme->getValueBool("",&bValue)) m_BOData[bo_ViewHidden			].m_original = bValue;
 
-	for (UT_uint32 i = 0; i < count; i++)
+	for (i = 0; i < count; i++)
 		{
 			BoolOption bo = static_cast<BoolOption>(i);
 
@@ -971,10 +951,6 @@ void AP_PreferenceScheme::saveChanges()
 	if (m_BOData[bo].m_current != m_BOData[bo].m_original)
 		m_pPrefsScheme->setValueBool(XAP_PREF_KEY_SaveContextGlyphs,				 m_BOData[bo].m_current);
 
-	bo = bo_GlyphShaping;
-	if (m_BOData[bo].m_current != m_BOData[bo].m_original)
-		m_pPrefsScheme->setValueBool(XAP_PREF_KEY_UseHebrewContextGlyphs,			 m_BOData[bo].m_current);
-
 	// NOT (YET?) IMPLEMENTED: m_pPrefsScheme->setValueBool("", m_BOData[bo_HighlightMisspelled	].m_current);
 
 	bo = bo_IgnoreNumbered;
@@ -1007,10 +983,6 @@ void AP_PreferenceScheme::saveChanges()
 
 	// TODO: m_pPrefsScheme->setValueBool("", m_BOData[bo_ScreenColor				].m_current);
 
-	bo = bo_SmartQuotes;
-	if (m_BOData[bo].m_current != m_BOData[bo].m_original)
-		m_pPrefsScheme->setValueBool(XAP_PREF_KEY_SmartQuotesEnable,				 m_BOData[bo].m_current);
-
 	bo = bo_Splash;
 	if (m_BOData[bo].m_current != m_BOData[bo].m_original)
 		m_pPrefsScheme->setValueBool( AP_PREF_KEY_ShowSplash,						 m_BOData[bo].m_current);
@@ -1190,7 +1162,6 @@ void AP_PreferenceScheme::lookupDefaultOptionValues()
 	pScheme->getValueBool(XAP_PREF_KEY_DirMarkerAfterClosingParenthesis,	&(m_BOData[bo_DirectionMarkers	].m_default));
 	pScheme->getValueBool( AP_PREF_KEY_DefaultDirectionRtl,					&(m_BOData[bo_DirectionRTL		].m_default));
 	pScheme->getValueBool(XAP_PREF_KEY_SaveContextGlyphs,					&(m_BOData[bo_GlyphSaveVisual	].m_default));
-	pScheme->getValueBool(XAP_PREF_KEY_UseHebrewContextGlyphs,				&(m_BOData[bo_GlyphShaping		].m_default));
 	// NOT (YET?) IMPLEMENTED: pScheme->getValueBool("",&(m_BOData[bo_HighlightMisspelled	].m_default));
 	pScheme->getValueBool( AP_PREF_KEY_SpellCheckNumbers,					&(m_BOData[bo_IgnoreNumbered	].m_default)); // TODO: Is this reversed?
 	pScheme->getValueBool( AP_PREF_KEY_SpellCheckCaps,						&(m_BOData[bo_IgnoreUppercase	].m_default)); // TODO: Is this reversed?
@@ -1201,7 +1172,6 @@ void AP_PreferenceScheme::lookupDefaultOptionValues()
 	pScheme->getValueBool( AP_PREF_KEY_RulerVisible,						&(m_BOData[bo_Ruler				].m_default));
 	// NOT (YET?) IMPLEMENTED: pScheme->getValueBool("",&(m_BOData[bo_SaveScheme			].m_default));
 	// TODO: pScheme->getValueBool("",&(m_BOData[bo_ScreenColor			].m_default));
-	pScheme->getValueBool(XAP_PREF_KEY_SmartQuotesEnable,					&(m_BOData[bo_SmartQuotes		].m_default));
 	pScheme->getValueBool( AP_PREF_KEY_ShowSplash,							&(m_BOData[bo_Splash			].m_default));
 	pScheme->getValueBool( AP_PREF_KEY_StatusBarVisible,					&(m_BOData[bo_StatusBar			].m_default));
 	// NOT (YET?) IMPLEMENTED: pScheme->getValueBool("",&(m_BOData[bo_SuggestCorrections	].m_default));
