@@ -546,28 +546,34 @@ void GR_MathManager::initialize(void)
 	// load the gtkmathview settings and operator dictionaries from the private user directory, ...
 	UT_UTF8String userConfDir(pApp->getUserPrivateDirectory());
 	UT_UTF8String userDictDir(pApp->getUserPrivateDirectory());
+	UT_UTF8String userCombiningDictDir(pApp->getUserPrivateDirectory());
 	UT_UTF8String userLocalDictDir(pApp->getUserPrivateDirectory());
 #if defined(WIN32)
 	userConfDir += "\\math\\gtkmathview.conf.xml";
 	userDictDir += "\\math\\dictionary.xml";
+	userCombiningDictDir += "\\math\\dictionary-combining.xml";
 	userLocalDictDir += "\\math\\dictionary-local.xml";
 #else
 	userConfDir += "/math/gtkmathview.conf.xml";
 	userDictDir += "/math/dictionary.xml";
+	userCombiningDictDir += "/math/dictionary-combining.xml";
 	userLocalDictDir += "/math/dictionary-local.xml";
 #endif
 
 	// ... or from the (common) AbiSuite directory
 	UT_UTF8String libConfDir(pApp->getAbiSuiteLibDir());
 	UT_UTF8String libDictDir(pApp->getAbiSuiteLibDir());
+	UT_UTF8String libCombiningDictDir(pApp->getAbiSuiteLibDir());
 	UT_UTF8String libLocalDictDir(pApp->getAbiSuiteLibDir());
 #if defined(WIN32)	 
 	libConfDir += "\\math\\gtkmathview.conf.xml";
 	libDictDir += "\\math\\dictionary.xml";
+	libCombiningDictDir += "\\math\\dictionary-combining.xml";
 	libLocalDictDir += "\\math\\dictionary-local.xml";
 #else
 	libConfDir += "/math/gtkmathview.conf.xml";
 	libDictDir += "/math/dictionary.xml";
+	libCombiningDictDir += "/math/dictionary-combining.xml";
 	libLocalDictDir += "/math/dictionary-local.xml";
 #endif
 
@@ -595,16 +601,24 @@ void GR_MathManager::initialize(void)
 	if (const char * resources = getenv("ABIWORD_COCOA_BUNDLED_RESOURCES"))
 	{
 		UT_UTF8String bundleDictDir(resources);
+		UT_UTF8String bundleCombiningDictDir(resources);
 		UT_UTF8String bundleLocalDictDir(resources);
+
 		bundleDictDir += "/gtkmathview/dictionary.xml";
+		bundleCombiningDictDir += "/gtkmathview/dictionary-combining.xml";
 		bundleLocalDictDir += "/gtkmathview/dictionary-local.xml";
+
 		configuration->add("dictionary/path", bundleDictDir.utf8_str());
+		configuration->add("dictionary/path", bundleCombiningDictDir.utf8_str());
 		configuration->add("dictionary/path", bundleLocalDictDir.utf8_str());
 	}
 #endif
 	configuration->add("dictionary/path", libDictDir.utf8_str());
+	configuration->add("dictionary/path", libCombiningDictDir.utf8_str());
 	configuration->add("dictionary/path", libLocalDictDir.utf8_str());
+
 	configuration->add("dictionary/path", userDictDir.utf8_str());
+	configuration->add("dictionary/path", userCombiningDictDir.utf8_str());
 	configuration->add("dictionary/path", userLocalDictDir.utf8_str());
 
 	SmartPtr<GR_Abi_MathGraphicDevice> mathGraphicDevice 
@@ -630,7 +644,18 @@ void GR_MathManager::_loadMathML(UT_sint32 uid, UT_UTF8String & sMathBuf)
 {
 	SmartPtr<libxml2_MathView> pMathView = m_vecMathView.getNthItem(uid);
 	UT_return_if_fail(pMathView);
-	pMathView->loadBuffer(sMathBuf.utf8_str());
+	UT_DEBUGMSG(("loading |%s| \n",sMathBuf.utf8_str()));
+	bool b = pMathView->loadBuffer(sMathBuf.utf8_str());
+	if(!b)
+	{
+		UT_DEBUGMSG(("Attempt to load |%s| \n failed \n",sMathBuf.utf8_str()));
+
+		UT_UTF8String sFailed = "<math xmlns='http://www.w3.org/1998/Math/MathML' display='inline'><merror><mtext>";
+		sFailed += "failed"; // TODO: need a better message!
+		sFailed += "</mtext></merror></math>";
+
+		pMathView->loadBuffer(sFailed.utf8_str());
+	}
 }
 
 void GR_MathManager::setDefaultFontSize(UT_sint32 uid, UT_sint32 iSize)
@@ -740,6 +765,10 @@ bool GR_MathManager::updatePNGSnapshot(AD_Document * pDoc, UT_Rect & rec,
 
 	GR_Painter painter(getGraphics());
 	GR_Image * pImage = painter.genImageFromRectangle(rec);
+	if(pImage == NULL)
+	{
+	    return false;
+	}
 	UT_ByteBuf * pBuf = NULL;
 
 	pImage->convertToBuffer(&pBuf);
@@ -762,7 +791,14 @@ bool GR_MathManager::modify(UT_sint32 uid)
 void GR_MathManager::initializeEmbedView(UT_sint32 uid)
 {
 	SmartPtr<libxml2_MathView>  pMathView = m_vecMathView.getNthItem(uid);
+	//	printf("pMathView uid is %d \n",uid);
 	UT_return_if_fail(pMathView);
+	// printf("Dirty Layout is set \n");
+	pMathView->setDirtyLayout();
+	UT_return_if_fail(pMathView->getMathMLNamespaceContext());
+	UT_return_if_fail(pMathView->getMathMLNamespaceContext()->getGraphicDevice());
+	// printf("Clear Cache is called \n");
+	pMathView->getMathMLNamespaceContext()->getGraphicDevice()->clearCache();
 }
 
 void GR_MathManager::loadEmbedData(UT_sint32 uid)
@@ -788,7 +824,7 @@ void GR_MathManager::loadEmbedData(UT_sint32 uid)
 		bFoundDataID = m_pDoc->getDataItemDataByName(pszDataID, 
 						const_cast<const UT_ByteBuf **>(&pByteBuf),
 						NULL, NULL);
-
+		UT_return_if_fail(pByteBuf && bFoundDataID);
 		UT_UCS4_mbtowc myWC;
 		sMathML.appendBuf( *pByteBuf, myWC);
 	}
@@ -796,7 +832,7 @@ void GR_MathManager::loadEmbedData(UT_sint32 uid)
 	UT_return_if_fail(bFoundDataID);
 	UT_return_if_fail(pszDataID);
 	UT_DEBUGMSG(("MATH ML string is... \n %s \n",sMathML.utf8_str()));
-
+	// printf("MATH ML string is... \n %s \n",sMathML.utf8_str());
 	_loadMathML(uid, sMathML);
 }
 
