@@ -1628,7 +1628,7 @@ bool ODe_Style_Style::GraphicProps::isEmpty() const {
  */
 void ODe_Style_Style::GraphicProps::
 fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
-    const XML_Char* pValue;
+    const XML_Char* pValue = NULL;
     bool ok;
     
     // Left border
@@ -1636,7 +1636,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     ok = rAP.getProperty("left-style", pValue);
     UT_ASSERT (ok && pValue != NULL);
 
-    if (*pValue == '0') {
+    if (pValue && (*pValue == '0')) {
         m_borderLeft = "none";
     } else {
         ok = rAP.getProperty("left-thickness", pValue);
@@ -1660,7 +1660,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     ok = rAP.getProperty("right-style", pValue);
     UT_ASSERT (ok && pValue != NULL);
     
-    if (*pValue == '0') {
+    if (pValue && (*pValue == '0')) {
         m_borderRight = "none";
     } else {
         ok = rAP.getProperty("right-thickness", pValue);
@@ -1684,7 +1684,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     ok = rAP.getProperty("top-style", pValue);
     UT_ASSERT (ok && pValue != NULL);
     
-    if (*pValue == '0') {
+    if (pValue && (*pValue == '0')) {
         m_borderTop = "none";
     } else {
         ok = rAP.getProperty("top-thickness", pValue);
@@ -1709,7 +1709,7 @@ fetchAttributesFromAbiProps(const PP_AttrProp& rAP) {
     ok = rAP.getProperty("bot-style", pValue);
     UT_ASSERT (ok && pValue != NULL);
     
-    if (*pValue == '0') {
+    if (pValue && (*pValue == '0')) {
         m_borderBottom = "none";
     } else {
         ok = rAP.getProperty("bot-thickness", pValue);
