@@ -144,13 +144,19 @@ UT_Error IE_Exp_OpenDocument::_writeDocument(void)
     DELETEP(pAbiDocListener);
     DELETEP(pAbiDocListenerImpl);
     
-    docData.doPostListeningWork();
+    if (!docData.doPostListeningWork()) {
+        return UT_ERROR;
+    }
     
     ////
     // Write content and styles
         
-    docData.writeStylesXML(m_odt);
-    docData.writeContentXML(m_odt);
+    if (!docData.writeStylesXML(m_odt)) {
+        return UT_ERROR;
+    }
+    if (!docData.writeContentXML(m_odt)) {
+        return UT_ERROR;
+    }
 
     return UT_OK;
 }
