@@ -107,9 +107,11 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         const ODi_Style_Style* pStyle = m_pStyles->getSectionStyle(pStyleName,
                                                         m_bOnContentStream);
                                                         
-        UT_UTF8String props;
-        
-        pStyle->getAbiPropsAttrString(props);
+        UT_UTF8String props = "";
+
+        if (pStyle) {        
+            pStyle->getAbiPropsAttrString(props);
+        }
         
         
         // If it don't have any properties it's useless.
@@ -149,7 +151,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         pStyle = m_pStyles->getParagraphStyle(pStyleName, m_bOnContentStream);
         UT_ASSERT(pStyle);
         
-        if (pStyle->isAutomatic()) {
+        if (pStyle && (pStyle->isAutomatic())) {
 
             if (pStyle->getParent() != NULL) {
                 m_headingStyles.ins(UT_UTF8String(pOutlineLevel),
@@ -162,9 +164,12 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
                 // (the TOC will not be displayed correctly, though).
             }
             
-        } else {
+        } else if (pStyle) {
             m_headingStyles.ins(UT_UTF8String(pOutlineLevel),
                                 pStyle->getDisplayName());
+        } else {
+            UT_ASSERT(UT_SHOULD_NOT_HAPPEN);
+            // pStyle is NULL
         }
         
         // It's so big that it deserves its own function.
@@ -450,6 +455,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         // We're inside a table cell, parsing its text contents.
         m_inAbiSection = true;
         m_bOnContentStream = true;
+        m_openedFirstAbiSection = true;
         
     }  else if (!UT_strcmp(pName, "text:note")) {
 
@@ -463,7 +469,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
         UT_uint32 id;
         const ODi_NotesConfiguration* pNotesConfig;
         const ODi_Style_Style* pStyle = NULL;
-        const UT_UTF8String* pCitationStyleName;
+        const UT_UTF8String* pCitationStyleName = NULL;
         UT_uint8 i;
         bool isFootnote;
         const XML_Char* pNoteClass;
@@ -508,7 +514,7 @@ void ODi_TextContent_ListenerState::startElement (const XML_Char* pName,
             ppAtts[i++] = "endnote-id";
         }
         ppAtts[i++] = m_currentNoteId.utf8_str();
-        if (!pCitationStyleName->empty() && pStyle != NULL) {
+        if (pCitationStyleName && (!pCitationStyleName->empty()) && (pStyle != NULL)) {
             ppAtts[i++] = "style";
             ppAtts[i++] = pStyle->getDisplayName().utf8_str();
         }
@@ -791,7 +797,7 @@ void ODi_TextContent_ListenerState::_insureInSection(
     
     
     const ODi_StartTag* pStartTag;
-    UT_UTF8String props;
+    UT_UTF8String props = "";
     
     // Now we open an abi <section> according to the OpenDocument parent
     // section, if there is one.
@@ -806,7 +812,9 @@ void ODi_TextContent_ListenerState::_insureInSection(
         UT_ASSERT(pStyleName != NULL);
         
         pStyle = m_pStyles->getSectionStyle(pStyleName, m_bOnContentStream);
-        pStyle->getAbiPropsAttrString(props);
+        if (pStyle) {
+            pStyle->getAbiPropsAttrString(props);
+        }
         
         
         // If it don't have any properties it's useless.
@@ -984,41 +992,45 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
             // Use the default style
             pStyle = m_pStyles->getDefaultParagraphStyle();
         }
-        
 
-        if (pStyle!=NULL && !pStyle->getMasterPageName()->empty()) {
-            bool isFirstAbiSection = !m_openedFirstAbiSection;
-            
-            _insureInSection(pStyle->getMasterPageName());
-            
-            if (!isFirstAbiSection) {
-                // We must be changing the master page style. A page break must
-                // be inserted before doing this change (as the OpenDocument
-                // standard say).
+        // We can't define new sections from inside a table cell
+        if (!m_rElementStack.hasElement("table:table-cell")) {
+
+            if (pStyle!=NULL && !pStyle->getMasterPageName()->empty()) {
+                bool isFirstAbiSection = !m_openedFirstAbiSection;
                 
-                // Append an empty paragraph with this one char
-                UT_UCSChar ucs = UCS_FF;
-                m_pAbiDocument->appendStrux(PTX_Block, NULL);
-                m_pAbiDocument->appendSpan (&ucs, 1);
-            }
-        } else {
-            _insureInSection();
-            
-            // Should we insert a break before this paragraph?
-            if (pStyle != NULL && !pStyle->getBreakBefore().empty()) {
-                UT_UCSChar ucs;
-                if (pStyle->getBreakBefore() == "page") {
-                    ucs = UCS_FF;
-                    // Append an empty paragraph with this one char
-                    m_pAbiDocument->appendStrux(PTX_Block, NULL);
-                    m_pAbiDocument->appendSpan (&ucs, 1);
-                } else if (pStyle->getBreakBefore() == "column") {
-                    ucs = UCS_VTAB;
+                _insureInSection(pStyle->getMasterPageName());
+                
+                if (!isFirstAbiSection) {
+                    // We must be changing the master page style. A page break must
+                    // be inserted before doing this change (as the OpenDocument
+                    // standard say).
+                    
                     // Append an empty paragraph with this one char
+                    UT_UCSChar ucs = UCS_FF;
                     m_pAbiDocument->appendStrux(PTX_Block, NULL);
                     m_pAbiDocument->appendSpan (&ucs, 1);
                 }
+            } else {
+                _insureInSection();
+                
+                // Should we insert a break before this paragraph?
+                if (pStyle != NULL && !pStyle->getBreakBefore().empty()) {
+                    UT_UCSChar ucs;
+                    if (pStyle->getBreakBefore() == "page") {
+                        ucs = UCS_FF;
+                        // Append an empty paragraph with this one char
+                        m_pAbiDocument->appendStrux(PTX_Block, NULL);
+                        m_pAbiDocument->appendSpan (&ucs, 1);
+                    } else if (pStyle->getBreakBefore() == "column") {
+                        ucs = UCS_VTAB;
+                        // Append an empty paragraph with this one char
+                        m_pAbiDocument->appendStrux(PTX_Block, NULL);
+                        m_pAbiDocument->appendSpan (&ucs, 1);
+                    }
+                }
             }
+
         }
         
 
@@ -1026,23 +1038,26 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
         i = 0;
 
         if (bIsListParagraph && !m_alreadyDefinedAbiParagraphForList) {
-            ODi_ListLevelStyle* pListLevelStyle;
+            ODi_ListLevelStyle* pListLevelStyle = NULL;
             
             m_alreadyDefinedAbiParagraphForList = true;
-            
-            pListLevelStyle = m_pCurrentListStyle->getLevelStyle(m_listLevel);
+            if (m_pCurrentListStyle) {
+                pListLevelStyle = m_pCurrentListStyle->getLevelStyle(m_listLevel);
+            }
             
             sprintf(listLevel, "%u", m_listLevel);
             
             ppAtts[i++] = "level";
             ppAtts[i++] = listLevel;
-            ppAtts[i++] = "listid";
-            ppAtts[i++] = pListLevelStyle->getAbiListID()->utf8_str();
+            if (pListLevelStyle && pListLevelStyle->getAbiListID() && pListLevelStyle->getAbiListParentID()) {
+                ppAtts[i++] = "listid";
+                ppAtts[i++] = pListLevelStyle->getAbiListID()->utf8_str();
             
-            // Is this really necessary? Because we already have this info on
-            // the <l> tag.
-            ppAtts[i++] = "parentid";
-            ppAtts[i++] = pListLevelStyle->getAbiListParentID()->utf8_str();
+                // Is this really necessary? Because we already have this info on
+                // the <l> tag.
+                ppAtts[i++] = "parentid";
+                ppAtts[i++] = pListLevelStyle->getAbiListParentID()->utf8_str();
+            }
             
             if (pStyle!=NULL) {
                 if (pStyle->isAutomatic()) {
@@ -1057,11 +1072,12 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
                 }
             }
 
-
-            pListLevelStyle->getAbiProperties(props, pStyle);
+            if (pListLevelStyle) {
+                pListLevelStyle->getAbiProperties(props, pStyle);
                 
-            ppAtts[i++] = "props";
-            ppAtts[i++] = props.utf8_str();
+                ppAtts[i++] = "props";
+                ppAtts[i++] = props.utf8_str();
+            }
                 
             ppAtts[i] = 0; // Marks the end of the attributes list.
             ok = m_pAbiDocument->appendStrux(PTX_Block,
@@ -1133,15 +1149,23 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
             m_pAbiDocument->appendStrux(PTX_Block, (const XML_Char**)ppAtts);
         }
 
+        // We now accept text
+        m_bAcceptingText = true;
 
         if (m_pendingNoteAnchorInsertion) {
-            UT_ASSERT(!m_currentNoteId.empty());
+            m_pendingNoteAnchorInsertion = false;
+
+            UT_return_if_fail(!m_currentNoteId.empty());
             
             const XML_Char* pNoteClass;
+            const ODi_StartTag* pStartTag;
         
-            pNoteClass = m_rElementStack.getStartTag(1)->
-                                getAttributeValue("text:note-class");
-            UT_ASSERT(pNoteClass != NULL);
+            pStartTag = m_rElementStack.getClosestElement("text:note", 1);
+            UT_return_if_fail (pStartTag != NULL);
+            
+            pNoteClass = pStartTag->getAttributeValue("text:note-class");
+                                
+            UT_return_if_fail(pNoteClass != NULL);
             
             ppAtts[0] = "type";
             if (!UT_strcmp(pNoteClass, "footnote")) {
@@ -1158,13 +1182,8 @@ void ODi_TextContent_ListenerState::_startParagraphElement (const XML_Char* pNam
             ppAtts[4] = 0;
             
             ok = m_pAbiDocument->appendObject(PTO_Field, ppAtts);
-            UT_ASSERT(ok);
-            
-            m_pendingNoteAnchorInsertion = false;
+            UT_ASSERT(ok);           
         }
-
-        // We now accept text
-        m_bAcceptingText = true;
 }
 
 
