@@ -659,14 +659,14 @@ UT_Error IE_Imp_OpenWriter::importFile(const char * szFilename)
   
   UT_Error err = UT_OK;
 
-  if ( UT_OK != (err = _handleMimetype ()))
-    return err;
-  if ( UT_OK != (err = _handleMetaStream ()))
-    return err;
-  if ( UT_OK != (err = _handleStylesStream ()))
-    return err;
+  if ( UT_OK != _handleMimetype ())
+    ; // TODO: give warning about missing mimetype stream
+  if ( UT_OK != _handleMetaStream ())
+    ; // TODO: give warning about missing meta.xml stream
+  if ( UT_OK != _handleStylesStream ())
+    ; // TODO: give warning about missing styles.xml stream
   if ( UT_OK != (err = _handleContentStream ()))
-    return err;
+    return err; // abort because content.xml stream is compulsory
     
   return UT_OK;
 }
@@ -1135,7 +1135,11 @@ private:
 UT_Error IE_Imp_OpenWriter::_handleStylesStream ()
 {
   m_pSSListener = new OpenWriter_StylesStream_Listener(this, m_bOpenDocument);
-  return handleStream (m_oo, "styles.xml", *m_pSSListener);
+  // Collect styles from both styles.xml and content.xml streams
+  UT_Error result1 = handleStream (m_oo, "styles.xml", *m_pSSListener);
+  UT_Error result2 = handleStream (m_oo, "content.xml", *m_pSSListener);
+  // return the biggest negative value or 0 if both are UT_OK
+  return (result1 < result2 ? result1 : result2);
 }
 
 /*****************************************************************************/
@@ -1465,6 +1469,9 @@ private:
     const XML_Char * height = UT_getAttribute ("svg:height", atts);
     const XML_Char * href   = UT_getAttribute ("xlink:href", atts);
 
+    if (width == NULL || height == NULL || href == NULL)
+        return; //don't crash on invalid images
+
     m_imgCnt++;
 
     UT_ByteBuf img_buf;
