@@ -26,6 +26,7 @@
 #include "ut_string.h"
 #include "xap_App.h"
 #include "xap_Frame.h"
+#include "ie_impexp_DocBook.h"
 #include "ie_imp_DocBook.h"
 #include "ie_types.h"
 #include "pd_Document.h"
@@ -108,27 +109,6 @@ IE_Imp_DocBook::IE_Imp_DocBook(PD_Document * pDocument)
 /*****************************************************************/
 /*****************************************************************/
 
-#define TT_OTHER		0               // anything else
-#define TT_DOCUMENT	        1		// a document <book>
-#define TT_SECTION              2               // card or section
-#define TT_BLOCK		3		// a paragraph <para>
-#define TT_PHRASE               4               // formatted text
-#define TT_EMPHASIS             5               // emphasized (italic) text
-#define TT_SUPERSCRIPT          6               // superscript
-#define TT_SUBSCRIPT            7               // subscript
-#define TT_BLOCKQUOTE           8               // block quote
-#define TT_BRIDGEHEAD           9               // heading  <bridgehead ...>
-#define TT_CHAPTER              10              // legacy abiword documents
-#define TT_TITLE                11              // title
-#define	TT_PAGEBREAK		12
-#define	TT_PLAINTEXT		13
-#define	TT_LINK			14
-#define	TT_ULINK		15
-#define	TT_BOOKMARK		16
-#define	TT_FIGURE		17
-#define	TT_MEDIAOBJECT		18
-#define	TT_IMAGEOBJECT		19
-#define	TT_IMAGEDATA		20
 
 struct _TokenTable
 {
@@ -149,10 +129,10 @@ static struct xmlToIdMapping s_Tokens[] =
 	{	"imagedata",		TT_IMAGEDATA		},
 	{	"imageobject",		TT_IMAGEOBJECT		},
 	{	"link",			TT_LINK			},
+	{	"literallayout",	TT_PLAINTEXT		},
 	{	"mediaobject",		TT_MEDIAOBJECT		},
 	{	"para",			TT_BLOCK		},
 	{       "phrase",               TT_PHRASE               },
-	{	"programlisting",	TT_PLAINTEXT		},
 	{       "section",              TT_SECTION              },
 	{       "subscript",            TT_SUBSCRIPT            },
 	{       "superscript",          TT_SUPERSCRIPT          },
