@@ -80,15 +80,18 @@ protected:
 	void				_closeSection(void);
 	void				_closeBlock(void);
 	void				_closeSpan(void);
+	void				_closeAnchor(void);
+	void				_closeHyperlink(void);
 	void				_openParagraph(PT_AttrPropIndex api);
 	void				_openSection(PT_AttrPropIndex api);
 	void				_openSpan(PT_AttrPropIndex api);
 	char *				_stripSuffix(const char* from, char delimiter);
 
   void _openTable(PT_AttrPropIndex api) ;
-  void _closeTable();
+  void _closeTable(void);
   void _openCell(PT_AttrPropIndex api);
-  void _closeCell();
+  void _closeCell(void);
+  void _closeRow(void);
 
 	void				_outputData(const UT_UCSChar * p, UT_uint32 length);
 	void				_handleDataItems();
@@ -97,7 +100,12 @@ protected:
 	IE_Exp_WML *		m_pie;
 	bool			m_bInBlock;
 	bool			m_bInSpan;
-        bool                 m_bWasSpace;
+	bool			m_bInAnchor;
+	bool			m_bInHyperlink;
+	bool			m_bInCell;
+	bool			m_bInRow;
+	bool			m_bInTable;
+	bool			m_bWasSpace;
 
 	const PP_AttrProp*	m_pAP_Span;
 
@@ -179,6 +187,11 @@ s_WML_Listener::s_WML_Listener(PD_Document * pDocument,
 	m_pie = pie;
 	m_bInBlock = false;
 	m_bInSpan = false;
+	m_bInAnchor = false;
+	m_bInHyperlink = false;
+	m_bInCell = false;
+	m_bInRow = false;
+	m_bInTable = false;
 	m_bWasSpace = false;
 
 	m_pie->write("<!DOCTYPE wml PUBLIC \"-//PHONE.COM//DTD WML 1.1//EN\"\n");
@@ -223,54 +236,107 @@ char *s_WML_Listener::_stripSuffix(const char* from, char delimiter)
     return fremove_s;
 }
 
+void s_WML_Listener::_closeAnchor()
+{
+  if(!m_bInAnchor)
+  {
+    return;
+  }
+
+  m_pie->write("</anchor>");
+  m_bInAnchor = false;
+}
+
+void s_WML_Listener::_closeHyperlink()
+{
+  if(!m_bInHyperlink)
+  {
+    return;
+  }
+
+  m_pie->write("</a>");
+  m_bInHyperlink = false;
+}
+
 void s_WML_Listener::_closeTable()
 {
-  m_pie->write("</table>\n");
+  if(!m_bInTable)
+  {
+    return;
+  }
+
+  _closeCell();
+  _closeRow();
+  m_pie->write("</table>\n</p>\n");
+  m_bInTable = false;
+}
+
+void s_WML_Listener::_closeRow()
+{
+  if(!m_bInRow || !m_bInTable)
+  {
+    return;
+  }
+
+  m_pie->write("</tr>\n");
+  m_bInRow = false;
 }
 
 void s_WML_Listener::_closeCell()
 {
+  if(!m_bInCell || !m_bInTable)
+  {
+    return;
+  }
+
   m_pie->write("</td>\n");
+  m_bInCell = false;
 
   if ( mTableHelper.getNumCols () == mTableHelper.getRight () )
     {
       // logical end of a row
-      m_pie->write("</tr>\n");
+      _closeRow();
     } 
 }
 
 void s_WML_Listener::_openTable(PT_AttrPropIndex api)
 {
+  if(m_bInTable)
+  {
+    return; //no nested tables
+  }
+
   UT_sint32 nCols = mTableHelper.getNumCols();
   
-  UT_String tableSpec = UT_String_sprintf("<table wml:columns=\"%d\">\n",nCols);
+  UT_String tableSpec = UT_String_sprintf("<p>\n<table columns=\"%d\">\n",nCols);
   m_pie->write(tableSpec.c_str(), tableSpec.size());
+  m_bInTable = true;
 }
 
 void s_WML_Listener::_openCell(PT_AttrPropIndex api)
 {
-  UT_sint32 rowspan = 1, colspan = 1;
-  
-  rowspan = mTableHelper.getBot() - mTableHelper.getTop();
-  colspan = mTableHelper.getRight() - mTableHelper.getLeft();
-  
-  if (mTableHelper.getLeft() == 0)
-    {
-      // beginning of a new row
-      m_pie->write("<tr>\n");
-    }
+  if(!m_bInTable)
+  {
+    return;
+  }
 
-  UT_String td ("<td");
-  
-  if (rowspan > 1)
-    td += UT_String_sprintf(" rowspan=\"%d\"", rowspan);
-  
-  if (colspan > 1)
-    td += UT_String_sprintf(" colspan=\"%d\"", colspan);
-  
-  td += ">\n";
-  
-  m_pie->write(td.c_str());
+  //wml 1.1 doesn't support colspan or rowspan
+
+  if (mTableHelper.getLeft() == 0)
+  {
+    _closeCell();
+    _closeRow();
+  }
+
+  if(!m_bInRow)
+  {
+    // beginning of a new row
+    m_pie->write("<tr>\n");
+    m_bInRow = true;
+  }
+
+  m_pie->write("<td>");
+  m_bInCell = true;
 }
 
 /*****************************************************************/
@@ -292,12 +358,18 @@ void s_WML_Listener::_openSection(PT_AttrPropIndex /* api*/)
 
 void s_WML_Listener::_closeBlock(void)
 {
-	if (!m_bInBlock)
+	_closeAnchor();
+	_closeHyperlink();
+
+	if(!m_bInBlock)
 	{
 		return;
 	}
+	if(!m_bInTable)
+	{
+		m_pie->write("</p>\n");
+	}
 
-	m_pie->write("</p>\n");
 	m_bInBlock = false;
 	return;
 }
@@ -308,6 +380,12 @@ void s_WML_Listener::_openParagraph(PT_AttrPropIndex api)
 
 	const PP_AttrProp * pAP = NULL;
 	bool bHaveProp = m_pDocument->getAttrProp(api,&pAP);
+
+	if (m_bInTable) //<p> tags aren't allowed inside of table-related tags
+	{
+		m_bInBlock = true;
+		return;
+	}
 	
 	if (bHaveProp && pAP)
 	{
@@ -421,12 +499,12 @@ bool s_WML_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 					
 					setlocale(LC_NUMERIC, old_locale);
 
-					m_pie->write(" >\n");
+					m_pie->write(" />");
 				}
 				return true;
 
 			case PTO_Field:
-				if(bHaveProp && pAP && pAP->getAttribute("type", szValue))
+				if(bHaveProp && pAP && pAP->getAttribute("type", szValue) && !(m_bInTable && (!m_bInRow || !m_bInCell)))
 				{
 					field = pcro->getField();
 
@@ -440,36 +518,46 @@ bool s_WML_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 			case PTO_Hyperlink:
 				if(bHaveProp && pAP && pAP->getAttribute("xlink:href", szValue))
 				{
-					m_pie->write("<a href=\"");
-					m_pie->write(szValue);
-					m_pie->write("\">");
+					UT_UTF8String url = szValue;
+					url.escapeURL();
+					_closeAnchor();
+					_closeHyperlink();
+					if(url.length() > 0)
+					{
+						m_pie->write("<a href=\"");
+						m_pie->write(url.utf8_str());
+						m_pie->write("\">");
+						m_bInHyperlink = true;
+					}
 				}
 				else
 				{
-					m_pie->write("</a>");
+					_closeHyperlink();
 				}
 				return true;
 
 			case PTO_Bookmark:
 				if(bHaveProp && pAP && pAP->getAttribute("type", szValue))
 				{
-					if( UT_XML_stricmp(szValue, "start") == 0 )
+					if( UT_XML_stricmp(szValue, "start") == 0 && m_bInHyperlink == 0 )
 					{
+						_closeAnchor(); //nested anchors not allowed
 						pAP->getAttribute("name", szValue);
 						m_pie->write("<anchor id=\"");
 						m_pie->write(szValue);
 						m_pie->write("\">");
+						m_bInAnchor = true;
 					}
 					else
 					{
-						m_pie->write("</anchor>");
+						_closeAnchor();						
 					}
 				}
 				return true;
 
 			default:
-				UT_ASSERT(0);
-				return false;
+				UT_ASSERT(UT_TODO);
+				return true;
 			}
 		}
 
@@ -477,8 +565,8 @@ bool s_WML_Listener::populate(PL_StruxFmtHandle /*sfh*/,
 		return true;
 		
 	default:
-		UT_ASSERT(0);
-		return false;
+		UT_ASSERT(UT_TODO);
+		return true;
 	}
 }
 
@@ -646,7 +734,7 @@ void s_WML_Listener::_handleDataItems()
 
 void s_WML_Listener::_openSpan(PT_AttrPropIndex api)
 {
-	if (!m_bInBlock)
+	if (!m_bInBlock || m_bInHyperlink || m_bInAnchor || (m_bInTable && (!m_bInRow || !m_bInCell)))
 	{
 		return;
 	}
@@ -724,7 +812,7 @@ void s_WML_Listener::_openSpan(PT_AttrPropIndex api)
 
 void s_WML_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 {
-	if (!m_bInBlock)
+	if (!m_bInBlock || (m_bInTable && (!m_bInRow || !m_bInCell)))
 	{
 		return;
 	}
@@ -754,6 +842,8 @@ void s_WML_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 			pData++;
 			break;
 
+		case UCS_VTAB:					// column break, export as a linebreak for now
+		case UCS_FF:					// page break, export as a linebreak for now
 		case UCS_LF:					// LF -- representing a Forced-Line-Break
 			sBuf += "<br/>";
 			pData++;
@@ -789,7 +879,7 @@ void s_WML_Listener::_outputData(const UT_UCSChar * data, UT_uint32 length)
 
 void s_WML_Listener::_closeSpan(void)
 {
-	if (!m_bInSpan)
+	if (!m_bInSpan || m_bInHyperlink || m_bInAnchor)
 		return;
 
 	const PP_AttrProp * pAP = m_pAP_Span;
