@@ -4,6 +4,7 @@
 #include "config.h"
 #endif
 #include "wv.h"
+#include "wvinternal.h"
 
 /*
 how this works,
@@ -27,7 +28,8 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
     U32 beginfc, endfc;
 	U32 stream_size;
     U32 begincp, endcp;
-    U8 chartype;
+    int ichartype;
+    U8  chartype;
     U16 eachchar;
     U32 para_fcFirst, para_fcLim = 0xffffffff;
     U32 dummy, nextpara_fcLim = 0xffffffff;
@@ -112,8 +114,8 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 
 
     /* get font list */
-    if ((wvQuerySupported (&ps->fib, NULL) == WORD6)
-	|| (wvQuerySupported (&ps->fib, NULL) == WORD7))
+    if ((ver == WORD6)
+	|| (ver == WORD7))
 	wvGetFFN_STTBF6 (&ps->fonts, ps->fib.fcSttbfffn, ps->fib.lcbSttbfffn,
 			 ps->tablefd);
     else
@@ -121,8 +123,8 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 			ps->tablefd);
 
     /*we will need the table of names to answer questions like the name of the doc */
-    if ((wvQuerySupported (&ps->fib, NULL) == WORD6)
-	|| (wvQuerySupported (&ps->fib, NULL) == WORD7))
+    if ((ver == WORD6)
+	|| (ver == WORD7))
       {
 	  wvGetSTTBF6 (&ps->anSttbfAssoc, ps->fib.fcSttbfAssoc,
 		       ps->fib.lcbSttbfAssoc, ps->tablefd);
@@ -174,8 +176,8 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
        we will need the paragraph and character bounds table to make decisions as 
        to where a para/char run begins and ends
      */
-    if ((wvQuerySupported (&ps->fib, NULL) == WORD6)
-	|| (wvQuerySupported (&ps->fib, NULL) == WORD7))
+    if ((ver == WORD6)
+	|| (ver == WORD7))
       {
 	  wvGetBTE_PLCF6 (&btePapx, &posPapx, &para_intervals,
 			  ps->fib.fcPlcfbtePapx, ps->fib.lcbPlcfbtePapx,
@@ -222,6 +224,13 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 		/* Formatting still lacking. This is just a start. */
 	    }
 	  wvHandleDocument (ps, DOCEND);
+	  wvReleaseSTTBF (&ps->anSttbfAssoc);
+	  wvReleaseSTTBF (&ps->Sttbfbkmk);
+	  wvFree (posChpx);
+	  wvFree (bteChpx);
+	  wvFree (btePapx);
+	  wvReleaseCLX (&ps->clx);
+	  wvReleaseSTSH (&ps->stsh);
 	  return;
       }
 
@@ -237,7 +246,8 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
     wvInitPAPX_FKP (&para_fkp);
     wvInitCHPX_FKP (&char_fkp);
 
-    wvHandleDocument (ps, DOCBEGIN);
+    if(wvHandleDocument (ps, DOCBEGIN))
+		goto  finish_processing;
 
 
 	/*get stream size for bounds checking*/
@@ -246,10 +256,11 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
     /*for each piece */
     for (piececount = 0; piececount < ps->clx.nopcd; piececount++)
       {
-	  chartype =
+	  ichartype =
 	      wvGetPieceBoundsFC (&beginfc, &endfc, &ps->clx, piececount);
-	  if(chartype==-1)
+	  if(ichartype==-1)
 		  break;
+	  chartype = (U8) ichartype;
 	  /*lvm007@aha.ru fix antiloop: check stream size */
 	  if(beginfc>stream_size || endfc>stream_size){
 		  wvError (
@@ -308,8 +319,7 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 		  {
 		      wvTrace (("j i is %x %d\n", j, i));
 		      section_dirty =
-			  wvGetSimpleSectionBounds (wvQuerySupported
-						    (&ps->fib, NULL), ps,
+			  wvGetSimpleSectionBounds (ver, ps,
 						    &sep, &section_fcFirst,
 						    &section_fcLim, i,
 						    &ps->clx, sed, &spiece,
@@ -331,8 +341,7 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 		if ((para_fcLim == 0xffffffff) || (para_fcLim == j))
 		  {
 		      wvReleasePAPX_FKP (&para_fkp);
-		      wvGetSimpleParaBounds (wvQuerySupported
-					     (&ps->fib, NULL), &para_fkp,
+		      wvGetSimpleParaBounds (ver, &para_fkp,
 					     &para_fcFirst, &para_fcLim,
 					     wvConvertCPToFC (i, &ps->clx),
 					     btePapx, posPapx, para_intervals,
@@ -362,21 +371,15 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 		if (j == para_fcFirst)
 		  {
 		      para_dirty =
-			  wvAssembleSimplePAP (wvQuerySupported
-					       (&ps->fib, NULL), &apap,
-					       para_fcLim, &para_fkp,
-					       &ps->stsh, ps->data);
+			  wvAssembleSimplePAP (ver, &apap, para_fcLim, &para_fkp, ps);
 
 		      /* test section */
 		      wvReleasePAPX_FKP (&para_fkp);
-		      wvGetSimpleParaBounds (wvQuerySupported
-					     (&ps->fib, NULL), &para_fkp,
+		      wvGetSimpleParaBounds (ver, &para_fkp,
 					     &dummy, &nextpara_fcLim,
 					     para_fcLim, btePapx, posPapx,
 					     para_intervals, ps->mainfd);
-		      wvAssembleSimplePAP (wvQuerySupported (&ps->fib, NULL),
-					   &ps->nextpap, nextpara_fcLim,
-					   &para_fkp, &ps->stsh, ps->data);
+		      wvAssembleSimplePAP (ver, &ps->nextpap, nextpara_fcLim, &para_fkp, ps);
 		      /* end test section */
 
 		      if ((apap.fInTable) && (!apap.fTtp))
@@ -423,8 +426,7 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 		  {
 		      wvTrace (("j i is %x %d\n", j, i));
 		      wvReleaseCHPX_FKP (&char_fkp);
-		      wvGetSimpleCharBounds (wvQuerySupported
-					     (&ps->fib, NULL), &char_fkp,
+		      wvGetSimpleCharBounds (ver, &char_fkp,
 					     &char_fcFirst, &char_fcLim, i,
 					     &ps->clx, bteChpx, posChpx,
 					     char_intervals, ps->mainfd);
@@ -456,10 +458,9 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 		  {
 		      wvTrace (("assembling CHP...\n"));
 		      /* a CHP's base style is in the para style */
-		      achp.istd = apap.istd;
+		      /* achp.istd = apap.istd; */
 		      char_dirty =
-			  wvAssembleSimpleCHP (wvQuerySupported
-					       (&ps->fib, NULL), &achp,
+				  wvAssembleSimpleCHP (ver, &achp, &apap,
 					       char_fcLim, &char_fkp,
 					       &ps->stsh);
 		      wvTrace (("CHP assembled.\n"));
@@ -504,6 +505,7 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 
       }
 
+ finish_processing:
     if (char_pendingclose)
       {
 	  wvInitCHP (&achp);
@@ -539,6 +541,18 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
     wvHandleDocument (ps, DOCEND);
     wvFree (posSedx);
     wvFree (sed);
+    wvFree(bkd);
+    wvFree(posBKD);
+    wvFree(ftxbx);
+    wvFree(txbxTxt); 
+#if defined(WIN32)
+   wvReleasePAPX_FKP (&para_fkp);
+   wvReleaseCHPX_FKP (&char_fkp);   
+
+   external_wvReleasePAPX_FKP ();
+   external_wvReleaseCHPX_FKP();
+#endif
+
 
     wvFree (ps->liststartnos);
     wvFree (ps->listnfcs);
@@ -549,10 +563,15 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
     wvReleaseLST (&ps->lst, ps->noofLST);
     wvReleaseLFO_records (&ps->lfo, &ps->lfolvl, &ps->lvl, ps->nooflvl);
     wvReleaseSTTBF (&ps->anSttbfAssoc);
+    wvReleaseSTTBF (&ps->Sttbfbkmk);
     wvFree (btePapx);
     wvFree (posPapx);
     wvFree (bteChpx);
     wvFree (posChpx);
+    wvFree (bkd);
+    wvFree (posBKD);
+    wvFree (txbxTxt);
+    wvFree (ftxbx);
 #if 0
     /* 
        so what, this is meaningless 
@@ -573,6 +592,7 @@ wvDecodeSimple (wvParseStruct * ps, subdocument whichdoc)
 	  wvFree (ps->vmerges);
       }
     wvFree (ps->cellbounds);
+	wvOLEFree(ps);
     tokenTreeFreeAll ();
 }
 
